@@ -260,20 +260,18 @@ class R3sponse(object):
 		for key in list(response.keys()):
 			value = response[key]
 			no_dict = False
-			try:
-				if isinstance(value, dict):
-					value = self.serialize(value)
-				else:
+			if isinstance(value, dict):
+				value = self.serialize(value)
+			else:
+				try:
+					value = ast.literal_eval(value)
+				except:
 					try:
-						value = ast.literal_eval(value)
-						value = self.serialize(value)
+						value = json.loads(value)
 					except:
-						try:
-							value = json.loads(value)
-							value = self.serialize(value)
-						except:
-							no_dict = True
-			except: a=1
+						no_dict = True
+				if no_dict == False and isinstance(value, dict):
+					value = self.serialize(value)
 			if no_dict == False: a=1
 			elif value in [True, "True", "true", "TRUE"]: value = True
 			elif value in [False, "False", "false", "FALSE"]: value = False
@@ -297,18 +295,7 @@ class R3sponse(object):
 			"message":None,
 			"error":None,
 	}):
-		if response["success"] in [True, "True", "true"]:
-			message = response["message"]
-			try:  del response["message"]
-			except: a=1
-			try:  del response["error"]
-			except: a=1
-			try:  del response["success"]
-			except: a=1
-			response = self.serialize(response)
-			return self.success_response(message, response)
-		else:
-			return self.error_response(response["error"])
+		return self.response(self.serialize(response))
 	class ResponseObject(object):
 		def __init__(self, attributes={
 			"success":False,
@@ -351,6 +338,15 @@ class R3sponse(object):
 							try: value = int(value)
 							except: a=1
 				self[key] = value
+		# unpack keys as tuple.
+		def unpack(self, 
+			# the variable keys (#1 parameter).
+			keys=[],
+		):
+			list = []
+			for key in keys:
+				list.append(key)
+			return list
 		# clean default values.
 		def clean(self):
 			for i in ["error", "message", "success"]:
